==> scummvm_1.9.0+dfsg.orig.tar.xz: scummvm-1.9.0/backends/platform/sdl/macosx/macosx.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef PLATFORM_SDL_MACOSX_H
#define PLATFORM_SDL_MACOSX_H

#include "backends/platform/sdl/posix/posix.h"

class OSystem_MacOSX : public OSystem_POSIX {
public:
	OSystem_MacOSX();

	virtual bool hasFeature(Feature f);

	virtual bool displayLogFile();

	virtual bool hasTextInClipboard();
	virtual Common::String getTextFromClipboard();

	virtual bool openUrl(const Common::String &url);

	virtual Common::String getSystemLanguage() const;

	virtual void init();
	virtual void initBackend();
	virtual void addSysArchivesToSearchSet(Common::SearchSet &s, int priority = 0);

protected:
	// Override createAudioCDManager() to get our Mac-specific
	// version.
	virtual AudioCDManager *createAudioCDManager();
};

#endif

==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/backends/platform/sdl/macosx/macosx.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef PLATFORM_SDL_MACOSX_H
#define PLATFORM_SDL_MACOSX_H

#include "backends/platform/sdl/posix/posix.h"

class OSystem_MacOSX : public OSystem_POSIX {
public:
	OSystem_MacOSX();
	~OSystem_MacOSX();

	virtual bool hasFeature(Feature f);

	virtual bool displayLogFile();

	virtual bool hasTextInClipboard();
	virtual Common::String getTextFromClipboard();
	virtual bool setTextInClipboard(const Common::String &text);

	virtual bool openUrl(const Common::String &url);

	virtual Common::String getSystemLanguage() const;

	virtual void init();
	virtual void initBackend();
	virtual void addSysArchivesToSearchSet(Common::SearchSet &s, int priority = 0);

	//Screenshots
	virtual Common::String getScreenshotsPath();

protected:
	virtual Common::String getDefaultLogFileName();

	// Override createAudioCDManager() to get our Mac-specific
	// version.
	virtual AudioCDManager *createAudioCDManager();
};

#endif
